==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "korniza kohore"

, "summary"
: "përmbledhje"

, "Total Timesheets"
: "Totali Tabelave kohore"

, "Billable Timesheets"
: "Tabela kohore të faturueshme"

, "Total Time"
: "Koha totale"

, "Time of Billable Timesheets"
: "Koha e tabelave kohore të faturueshme"

, "Description"
: "Përshkrim"

, "Detail"
: "Detaj"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Eksporto Tabelat kohore"

, "Export as ODS"
: "Eksporto si ODS"

, "Export as CSV"
: "Eksporto si CSV"

, "Export as ..."
: "Eksporto si..."

, "Timesheet, Timesheets"
: [
  "Tabelë kohore"
 ,"Tabela Kohore"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Dështoi"

, "Could not save {0}."
: "Nuk mund të ruhej {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Afati i rezervimit për këtë Llogari kohore është tejkaluar"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Marrëveshje"

, "without contract"
: "pa marrëveshje"

, "Add New Timeaccount"
: ""

, "Unit"
: "Njësi"

, "Unit Price"
: "Çmim njësie"

, "Factor"
: ""

, "Budget"
: "Buxhet"

, "Status"
: "Staus"

, "closed"
: "mbyllur"

, "open"
: "hapur"

, "Cleared In"
: "Pastruar në"

, "Cleared at"
: "Pastruar në"

, "Cost Center"
: "Qëndra e kostove"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Tabelat kohore janë të faturueshme"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Llogaria kohore"
 ,"Llogaritë kohore"

]
, "Number"
: "Numër"

, "Title"
: "Titull"

, "Access"
: "Hyrje"

, "Permissions"
: "Autorizime"

, "Time Account - Billed"
: "Llogari kohore - Faturuar"

, "not yet billed"
: "e pafaturuar akoma"

, "to bill"
: "për tu faturuar"

, "billed"
: "faturuar"

, "Time Account - Status"
: "Llogari kohore - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Rezervo tënden"

, "The grant to add Timesheets to this Timeaccount"
: "E drejta për të shtuar Tabela Kohore tek kjo Llogari kohore "

, "View All"
: "Shiko të gjitha"

, "The grant to view Timesheets of other users"
: "E drejta për të parë Tabelat Kohore të përdoruesve të tjerë"

, "Book All"
: "Rezervo të gjitha"

, "The grant to add Timesheets for other users"
: "E drejta për të shtuar Tabela Kohore për përdoruesit e tjerë"

, "Manage Clearing"
: "Menaxho Pastrimin"

, "The grant to manage clearing of Timesheets"
: "E drejta për të menaxhuar pastrimin e Tabelave Kohore"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Trego të mbyllurat"

, "Timesheets ODS export configuration"
: "Konfigurimi i eksportimit ODS të Tabelave kohore "

, "Use this configuration for the timesheet ODS export."
: "Përdor këtë konfigurim për eksportin ODS të tabelave kohore"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "paracaktuar"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "askush"

, "last week"
: "javën e shkuar"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Pastruar në"

, "Billed"
: "Faturuar"

, "Booking deadline"
: "Afati i fundit i rezervimit"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Llogari"

, "Time Account (Number - Title)"
: "Llogari Kohore (Numër - Titull)"

, "Billable"
: "E faturueshme"

, "Cleared"
: "E pastruar"

, "Date"
: "Datë"

, "Start time"
: "Koha e fillimit"

, "End time"
: ""

, "Duration"
: "Kohëzgjatja"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Llogari Kohore e mbyllur"

, "Timetracker"
: "Matësi kohor"

, "Timeaccounts to bill"
: "Llogari kohore për tu faturuar"

, "Timeaccounts not yet billed"
: "Llogari kohore akoma të pa faturuara"

, "Timeaccounts already billed"
: "Llogari kohore të faturuara "

, "My Timesheets today"
: "Tabelat e mia kohore sot"

, "My Timesheets this week"
: "Tabelat e mia kohore këtë javë"

, "My Timesheets last week"
: "Tabelat e mia kohore të javës së shkuar"

, "My Timesheets this month"
: "Tabelat e mia kohore këtë muaj"

, "My Timesheets last month"
: "Tabelat e mia kohore të muajit të shkuar"

, "Manage timeaccounts"
: "Menaxho llogaritë kohore"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Shto, modifiko dhe fshij llogaritë kohore (përfshirë të gjithë E drejta e tabelës kohore)"

, "Add timeaccounts"
: "Shto llogari kohore"

, "Manage shared timeaccount favorites"
: "Menaxho preferencialet e llogarive kohore të ndara"

, "Create or update shared timeaccount favorites"
: "Krijo ose përditëso llogari kohore preferenciale të ndara"

, "Manage shared timesheet favorites"
: "Menaxho preferenciale tabelash kohore të ndara"

, "Create or update shared timesheet favorites"
: "Krijo ose përditëso preferencialet e tabelave kohore të ndara"






, "Timesheet"
: "Tabelë kohore"

, "Timeaccount"
: ""

, "Time Account"
: "Llogaria kohore"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "korniza kohore"

, "summary"
: "përmbledhje"

, "Total Timesheets"
: "Totali Tabelave kohore"

, "Billable Timesheets"
: "Tabela kohore të faturueshme"

, "Total Time"
: "Koha totale"

, "Time of Billable Timesheets"
: "Koha e tabelave kohore të faturueshme"

, "Description"
: "Përshkrim"

, "Detail"
: "Detaj"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Eksporto Tabelat kohore"

, "Export as ODS"
: "Eksporto si ODS"

, "Export as CSV"
: "Eksporto si CSV"

, "Export as ..."
: "Eksporto si..."

, "Timesheet, Timesheets"
: [
  "Tabelë kohore"
 ,"Tabela Kohore"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: "Dështoi"

, "Could not save {0}."
: "Nuk mund të ruhej {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Afati i rezervimit për këtë Llogari kohore është tejkaluar"

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Marrëveshje"

, "without contract"
: "pa marrëveshje"

, "Add New Timeaccount"
: ""

, "Unit"
: "Njësi"

, "Unit Price"
: "Çmim njësie"

, "Factor"
: ""

, "Budget"
: "Buxhet"

, "Status"
: "Staus"

, "closed"
: "mbyllur"

, "open"
: "hapur"

, "Cleared In"
: "Pastruar në"

, "Cleared at"
: "Pastruar në"

, "Cost Center"
: "Qëndra e kostove"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Tabelat kohore janë të faturueshme"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Llogaria kohore"
 ,"Llogaritë kohore"

]
, "Number"
: "Numër"

, "Title"
: "Titull"

, "Access"
: "Hyrje"

, "Permissions"
: "Autorizime"

, "Time Account - Billed"
: "Llogari kohore - Faturuar"

, "not yet billed"
: "e pafaturuar akoma"

, "to bill"
: "për tu faturuar"

, "billed"
: "faturuar"

, "Time Account - Status"
: "Llogari kohore - Status"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Rezervo tënden"

, "The grant to add Timesheets to this Timeaccount"
: "E drejta për të shtuar Tabela Kohore tek kjo Llogari kohore "

, "View All"
: "Shiko të gjitha"

, "The grant to view Timesheets of other users"
: "E drejta për të parë Tabelat Kohore të përdoruesve të tjerë"

, "Book All"
: "Rezervo të gjitha"

, "The grant to add Timesheets for other users"
: "E drejta për të shtuar Tabela Kohore për përdoruesit e tjerë"

, "Manage Clearing"
: "Menaxho Pastrimin"

, "The grant to manage clearing of Timesheets"
: "E drejta për të menaxhuar pastrimin e Tabelave Kohore"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Trego të mbyllurat"

, "Timesheets ODS export configuration"
: "Konfigurimi i eksportimit ODS të Tabelave kohore "

, "Use this configuration for the timesheet ODS export."
: "Përdor këtë konfigurim për eksportin ODS të tabelave kohore"

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "paracaktuar"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "askush"

, "last week"
: "javën e shkuar"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Pastruar në"

, "Billed"
: "Faturuar"

, "Booking deadline"
: "Afati i fundit i rezervimit"

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "Llogari"

, "Time Account (Number - Title)"
: "Llogari Kohore (Numër - Titull)"

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "E faturueshme"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Datë"

, "Start time"
: "Koha e fillimit"

, "End time"
: ""

, "Duration"
: "Kohëzgjatja"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "Matësi kohor"

, "My Timesheets today"
: "Tabelat e mia kohore sot"

, "My Timesheets this week"
: "Tabelat e mia kohore këtë javë"

, "My Timesheets last week"
: "Tabelat e mia kohore të javës së shkuar"

, "My Timesheets this month"
: "Tabelat e mia kohore këtë muaj"

, "My Timesheets last month"
: "Tabelat e mia kohore të muajit të shkuar"

, "Timeaccounts to bill"
: "Llogari kohore për tu faturuar"

, "Timeaccounts not yet billed"
: "Llogari kohore akoma të pa faturuara"

, "Timeaccounts already billed"
: "Llogari kohore të faturuara "

, "Manage timeaccounts"
: "Menaxho llogaritë kohore"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: "Shto, modifiko dhe fshij llogaritë kohore (përfshirë të gjithë E drejta e tabelës kohore)"

, "Add timeaccounts"
: "Shto llogari kohore"

, "Manage shared timeaccount favorites"
: "Menaxho preferencialet e llogarive kohore të ndara"

, "Create or update shared timeaccount favorites"
: "Krijo ose përditëso llogari kohore preferenciale të ndara"

, "Manage shared timesheet favorites"
: "Menaxho preferenciale tabelash kohore të ndara"

, "Create or update shared timesheet favorites"
: "Krijo ose përditëso preferencialet e tabelave kohore të ndara"








, "Timesheet"
: "Tabelë kohore"

, "Timeaccount"
: ""

, "Time Account"
: "Llogaria kohore"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
